#
# spec file for package libical
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libical
Version:        1.0.1
Release:        12.1
%define sonum   1
Summary:        An Implementation of Basic iCAL Protocols
License:        MPL-1.0 or LGPL-2.1
Group:          Development/Libraries/C and C++
Url:            http://sourceforge.net/projects/freeassociation/
Source:         https://github.com/libical/libical/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch0:         reproducible-generator.patch
BuildRequires:  cmake >= 2.4
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libical is an open source implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package -n %{name}%{sonum}
Summary:        An Implementation of Basic iCAL Protocols
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{name}%{sonum}
Libical is an open source implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package devel
Summary:        Development files for libical, an implementation of basic iCAL protocols
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sonum} = %{version}

%description devel
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols. (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package devel-static
Summary:        Additional static library for development with libical
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description devel-static
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols. (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package doc
Summary:        Example source code for libical-using programs
Group:          Documentation/Other
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
Libical is an open source implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%prep
%setup -q
%patch0 -p1

%build
%cmake
make -j1

%install
%cmake_install
rm examples/CMakeLists.txt

# REMOVE AN UNNEEDED HIDDEN FILE
rm examples/.svnignore

%post -n %{name}%{sonum} -p /sbin/ldconfig

%postun -n %{name}%{sonum} -p /sbin/ldconfig

%files -n %{name}%{sonum}
%defattr(-,root,root)
%doc AUTHORS ReadMe.txt ReleaseNotes.txt COPYING LICENSE TEST THANKS TODO
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/libical.pc
%{_includedir}/ical.h
%{_includedir}/libical/
%{_libdir}/cmake/LibIcal/

%files devel-static
%defattr(-,root,root)
%{_libdir}/*.a

%files doc
%defattr(-,root,root)
%doc doc/*.txt
%doc examples/

%changelog
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop libical-sle12-abi.patch:
  use standard libical 1.0.1 ABI for SP2.
* Tue Feb  3 2015 coolo@suse.com
- add reproducible-generator.patch from debian bug report to
  get reproducible builds (and predicatable API actually)
* Fri Dec 26 2014 badshah400@gmail.com
- Update to version 1.0.1:
  + Bug fixes:
  - issue74: Do not escape double quote character
  - issue80,issue92: fix crashes using
    icaltimezone_load_builtin_timezone() recursively
  - Fix icalcomponent_foreach_recurrence() and large durations
    between recurrences (e.g. FREQ=YEARLY)
  - Properly handle UTCOFFSETs of the form +/-00mmss
  - Properly skip bogus dates (e.g. 2/30, 4/31) in
    RRULE:FREQ=MONTHLY
  - Properly handle RRULE:FREQ=MONTHLY;BYDAY;BYMONTHDAY when
    DTSTART isn't on BYDAY
  - Fix RRULE:FREQ=YEARLY;BYDAY;BYWEEKNO - MUST use ISO weeks
  - Properly skip bogus dates (e.g. 2/29) in
    RRULE:FREQ=YEARLY[;BYMONTH][;BYMONTHDAY]
  + Build fixes/features:
  - Autotools build system is removed
  - CMake version 2.8.9 (or higher) is required (was CMake
    version 2.4.0)
  - Add new -DSHARED_ONLY and -DSTATIC_ONLY CMake options
  - Remove -DSTATIC_LIBRARY CMake option
  - MSYS2 builds (fixed instructions)
  - Now can build api documentation with make docs
  + Update tzdata to version 2014g
  + Support added for schedule params: agent, status, force-send
  + Added a UID to the VFREEBUSY component
  + Allow dates > 2038 if sizeof(time_t) > 4
  + Add properties from draft-ietf-tzdist-service
  + Add support for RRULE:FREQ=YEARLY;BYDAY;BYYEARDAY and fixed
    RRULE:FREQ=YEARLY;BYYEARDAY with negative days
  + More regression tests added, in particular for recurrence
  + Almost all compile warnings silenced
  + A bunch of Coverity Scan warnings silenced
  + Package cmake macros installed by package.
- Add libical-sle12-abi.patch:
  use enum values used in prior SLE12 package, for ABI
  compatibility (bsc#954161).
- Drop 941609-typo-fix_icaltime_days_in_year.patch:
  fixed upstream (bsc#941609).
* Mon Oct 20 2014 cxiong@suse.com
- Add 941609-typo-fix_icaltime_days_in_year.patch:
  Typo fix "icaltime_days_in_year". This bug doesn't affect any
  functionality of SLE-12, backport for code correctness and
  completeness (bsc#941609).
* Fri Sep 26 2014 coolo@suse.com
- disable parallel build, too unreliable
* Thu Sep 18 2014 jengelh@inai.de
- Use %%cmake macros so that %%optflags reliably lands on the build
  command lines
- Improve on RPM group classification
- Drop strange Recommends: from libical-doc to libical1
  (the latter does not offer any directly-usable feature when
  the docs are installed).
- Documentation subpackage should be noarch
* Sat Jun 15 2013 schwab@linux-m68k.org
- Build with %%{optflags}
* Sun Jun  9 2013 toddrme2178@gmail.com
- New 1.x package.
  This version uses the cmake build system
- Add devel-static subpackage
- Remove unneeded buildrequires
- Changed license from MPL-1.1 to MPL-1.0.  That is the license
  listed in the COPYING file and the headers.
- Removed scripts directory from documentation.  Putting perl
  files in the documentation directory is apparently no longer
  allowed.
- Ran spec-cleaner
* Sat Jan 28 2012 jengelh@medozas.de
- Changed: The -devel subpackage should require the lib package,
  not the main one
* Sat Jan 28 2012 tabraham@novell.com
- Update to version 0.48
  + Allow duration specifications containing week along with day
    and time. even though this is against the RFC, but apparently
    we generate such durations so we need to be able to read them
    back.  + handle the case of the ATTACH type be explicitly set
    to URI + added a lock to avoid threading problems when
    icaltimezone_parse_zone_tab is called on multiple threads
  + bugfixes
- removed patches deprecated by this release:
  - libical-0.46-fix-race.patch
  - libical-0.46-fix-fatal-error-macro-usage.patch
  - libical-0.46-fix-endless-loop.patch
* Mon Jan 23 2012 cdenicolo@suse.com
- license update: MPL-1.1 or LGPL-2.1
  is a dual license: MPL-1.1 or LGPL-2.1
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sun Nov 20 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Mar 11 2011 gber@opensuse.org
- update to version 0.46
  + allow control over how components, properties and parameters
    with unknown names are handled
  + renamed static set_zone_directory() to set_zonedir()
  + added appropriate icaltime_* functions as methods to
    icaltimetype
  + added icaltimetype.datetime for converting a icaltimetype to a
    python datetime
  + added icalarray_copy for easy copying of icalarrays
  + renamed icaltimetype.datetime to icaltimetype.as_datetime and
    added icaltimetype.from_datetime staticmethod
  + bugfixes
- correct licensing information
- run autoreconf since tarball misses autconf autgenerated files
  (sf#3072673)
- added libical-0.46-fix-race.patch from upstream svn which fixes a
  race in populating builtin timezone components
- added libical-0.46-fix-fatal-error-macro-usage.patch from
  upstream svn in order to replace broken ICAL_ERRORS_ARE_FATAL
  preprocessor conditions with the correct check for the macros
  value (sf#3140405)
- added libical-0.46-fix-fatal-error-macro-usage.patch from
  upstream svn which fixes endless loop in the recurrence
  calculation (sf#3177380)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Jan  6 2010 jengelh@medozas.de
- Package baselibs.conf
- Enable parallel build
* Sun Sep 27 2009 msuman@gnome.org
- Update to version 0.44:
  + Memory leak fixes by Alvaro Manera
  + Various build fixes
- Fixes for rpmlint warnings, remove the '--enable-python' configure
  option as python bindings were broken sometime ago.
* Mon Jan 12 2009 msuman@suse.de
- Update to version 0.43:
  + Incorporates bugfixes submitted by the GNOME Evolution team.
  + New API call icaltimezone_set_tzid_prefix() to allow downstream
    applications to generate tzid's with custom namespaces.
* Sat Dec 20 2008 msuman@suse.de
- Use proper RPM macros in the spec file, remove unnecessary
  options passed to the configure script.
* Mon Dec  1 2008 dmueller@suse.de
- update to 0.42:
  * Fix for storing inline attachments
  * Safety fix when formatting date strings
  * compile / portability fixes
* Thu Nov 27 2008 wstephenson@suse.de
- Backport from 0.42:
  * Fix for storing inline attachments
  * Safety fix when formatting date strings
* Wed Oct 15 2008 dmueller@suse.de
- update to 0.40:
  * adopt new memory management semantics from the Evolution fork of libical,
  essentially every function now has a _r variant as well.
  * CMake build system in parallel
  * Crash fixes
* Tue Sep 16 2008 dmueller@suse.de
- update to 0.33:
  - Massive merges from KDE PIM's fork of libical
* Tue Sep  2 2008 dmueller@suse.de
- update to 0.32:
  - Massive merges from Evolution Data Server
  and other sources.
* Wed May  7 2008 coolo@suse.de
- fix rename from libical
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 29 2008 sf@suse.de
- update to 0.27
  - Merges some patches from KDE and Citadel.
  - Updates timezone data to tzdata 2007c.
  - merges the libical forks from KDE, Evolution and SourceForge.
  - Updates timezone data to tzdata 2005j.
- rename library package to libical0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Wed Jan 19 2005 sf@suse.de
- fix use of uninitialized variable
* Mon Mar 22 2004 sf@suse.de
-  remove some temporary /object files in examples
* Wed Mar 17 2004 ro@suse.de
- re-apply patch to make it build
* Fri Feb  6 2004 adrian@suse.de
- update to version 0.24 RC4
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Jul  3 2003 ro@suse.de
- added unpackaged files
* Fri Jan 17 2003 stark@suse.de
- update to cvs 20030116 for upcoming Mozilla 1.3
* Wed Dec 11 2002 stark@suse.de
- update to cvs 20021211 for Mozilla 1.3a
* Thu Oct 17 2002 stark@suse.de
- "update" to version 0.23a used and provided by mozilla.org
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jun 17 2002 meissner@suse.de
- rerun auto* tools
* Wed Apr 17 2002 rhafer@suse.de
- added missing header files to -devel subpackage
- moved *.so links to -devel subpackage
- uses %%{_libdir} now
* Tue Apr  2 2002 sf@suse.de
- initial version
